@@ -5,10 +5,13 @@ from RG.R2 import *
 from RG.PCA import *
 from RG.PLS import *
 from RG.mbPLS import *
+from RG.cPCA import *
 from RG.LDA import *
+from RG.PCA_ellipse import *
 
 
 from RG.colorspectra import *
+from RG.axabline import *
 
 from RG.center import *
 from RG.autoscale import *
