@@ -12,8 +12,8 @@ def regress(y, X):
 
     print('betas and confidence intervals')
         
-    out = pd.DataFrame({'low': b_int[:,0], 'b': b, 'high': b_int[:,1]})
-    print(out)
+    #out = pd.DataFrame({'low': b_int[:,0], 'b': b, 'high': b_int[:,1]})
+    #print(out)
     
     b = (b[np.newaxis]).T # Vector format for output
     
